@@ -8,6 +8,9 @@
 
 #include <powerdevilaction.h>
 
+#include <QMap>
+#include <QString>
+
 namespace PowerDevil::BundledActions
 {
 class DimDisplay : public PowerDevil::Action
@@ -29,11 +32,11 @@ private Q_SLOTS:
     void onUnavailablePoliciesChanged(PowerDevil::PolicyAgent::RequiredPolicies policies);
 
 private:
-    void setBrightnessHelper(int screenBrightness, int keyboardBrightness);
+    void setBrightnessHelper(const QMap<QString, int> &screenBrightness, int keyboardBrightness);
 
     std::chrono::milliseconds m_dimOnIdleTime{0};
 
-    int m_oldScreenBrightness = 0;
+    QMap<QString, int> m_oldScreenBrightness;
     int m_oldKeyboardBrightness = 0;
 
     PowerDevil::PolicyAgent::RequiredPolicies m_inhibitScreen = PowerDevil::PolicyAgent::None;
